@@ -41,6 +41,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/assistant.h>
 #include <gtkmm/base.h>
 #include <gtkmm/bin.h>
+#include <gtkmm/border.h>
 #include <gtkmm/box.h>
 #include <gtkmm/builder.h>
 #include <gtkmm/button.h>
@@ -54,6 +55,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/cellrendererpixbuf.h>
 #include <gtkmm/cellrendererprogress.h>
 #include <gtkmm/cellrendererspin.h>
+#include <gtkmm/cellrendererspinner.h>
 #include <gtkmm/cellrenderertext.h>
 #include <gtkmm/cellrenderertoggle.h>
 #include <gtkmm/colorbutton.h>
@@ -111,6 +113,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/misc.h>
 #include <gtkmm/notebook.h>
 #include <gtkmm/object.h>
+#include <gtkmm/offscreenwindow.h>
 #include <gtkmm/optionmenu.h>
 #include <gtkmm/paned.h>
 #include <gtkmm/pagesetup.h>
@@ -147,6 +150,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/settings.h>
 #include <gtkmm/sizegroup.h>
 #include <gtkmm/spinbutton.h>
+#include <gtkmm/spinner.h>
 #include <gtkmm/statusbar.h>
 #include <gtkmm/statusicon.h>
 #include <gtkmm/stock.h>
@@ -167,6 +171,7 @@ extern const int gtkmm_micro_version;
 #include <gtkmm/toolbar.h>
 #include <gtkmm/toolitem.h>
 #include <gtkmm/toolbutton.h>
+#include <gtkmm/toolpalette.h>
 #include <gtkmm/toggletoolbutton.h>
 #include <gtkmm/menutoolbutton.h>
 #include <gtkmm/tooltip.h>
